"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _boom = _interopRequireDefault(require("boom"));

var _mongodb = require("mongodb");

var _express = require("express");

var _oorsRouter = require("oors-router");

var _injectServices = _interopRequireDefault(require("../middlewares/injectServices"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  wrapHandler
} = _oorsRouter.helpers;

var _default = ({
  uploadMiddleware
}) => {
  const router = (0, _express.Router)();
  router.use(_injectServices.default);
  router.param('id', async (req, res, next, rawId) => {
    let id;

    try {
      id = (0, _mongodb.ObjectID)(rawId);
    } catch (err) {
      return next(err);
    }

    try {
      const file = await req.services.FileRepository.findById(id);

      if (!file) {
        return next(_boom.default.notFound(`Unable to find entity with id ${rawId}`));
      }

      req.fileEntity = file;
    } catch (err) {
      return next(err);
    }

    return next();
  });
  router.post('/files/upload', uploadMiddleware.single('file'), wrapHandler(req => req.services.File.createFromUpload(req.file)));
  router.get('/files/:id/download', async (req, res, next) => {
    try {
      const filePath = await req.services.File.getPath({
        file: req.fileEntity
      });
      res.sendFile(filePath);
    } catch (err) {
      next(err);
    }
  });
  return router;
};

exports.default = _default;