"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _ValidationError = _interopRequireDefault(require("oors/build/errors/ValidationError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class File {
  constructor({
    uploadDir,
    FileRepository,
    validateUpload
  }) {
    this.uploadDir = uploadDir;
    this.FileRepository = FileRepository;
    this.validateUpload = validateUpload;
  }

  removeFiles(files) {
    return Promise.all(files.map(file => this.removeFile(file)));
  }

  removeFile(file) {
    return _fsExtra.default.unlink(this.getPath({
      file
    }));
  }

  async createFromUpload(data) {
    if (!this.validateUpload(data)) {
      throw new _ValidationError.default(this.validateUpload.errors);
    }

    const {
      path: uploadPath,
      originalname: filename,
      size,
      mimetype: mimeType,
      destination: uploadDir
    } = data;
    const file = await this.FileRepository.createOne({
      filename: _path.default.basename(filename),
      extension: _path.default.extname(filename),
      size,
      mimeType,
      uploadedAt: new Date()
    });
    const destination = this.getPath({
      file,
      uploadDir
    });
    await _fsExtra.default.rename(uploadPath, destination);
    return file;
  }

  getPath({
    file,
    uploadDir
  }) {
    return _path.default.join(uploadDir || this.uploadDir, `${file._id}${file.extension}`);
  }

}

var _default = File;
exports.default = _default;